@@ -87,16 +87,17 @@ class Pynedra:
                 return dict_result
             return {}
 
-    def get_dicom(self) -> Dataset:
+    def get_dicom(self) -> Optional[Dataset]:
         """
         Get dicom image.
         """
+        dicom_content = None
         with self.session.get(str(self.get_url())) as results:
             if results.status_code == 200:
                 for chunk in results.iter_content(chunk_size=None, decode_unicode=True):
                     if chunk:
                         dicom_content = dcmread(io.BytesIO(chunk), force=True)
-                return dicom_content
+            return dicom_content
 
     def get_url(self) -> URI:
         """
